@@ -8,7 +8,9 @@ sas_collectcode <- function() {
     
 knitr::knit_hooks$set(collectcode = function(before, options, envir) {
     if (!before) {
-        if (options$engine %in% c("sas", "saslog", "sashtml", "sashtmllog")) {
+        if (options$engine %in% c("sas", "saslog", 
+                                  "sashtml", "sashtmllog", 
+                                  "sashtml5", "sashtml5log")) {
             autoexec <- file("autoexec.sas", open="at")
             writeLines(options$code, autoexec)
             close(autoexec)
